@@ -1,4 +1,4 @@
-# $Id: Alias.pm 46806 2017-07-26 15:48:10Z wsl $
+# $Id: Alias.pm 46832 2017-08-01 11:08:55Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/Database/Alias.pm $
 
 package UvT::Kiki::Database::Alias;
@@ -233,7 +233,7 @@ sub diff {
 	my $full = $self->full;
 	my $ab = $self->addressbook;
 	my @destinations = map { $_->full } @{$self->destinations};
-	my $diff = $ab ? "$full (in address book):\n" : "$full: (not in address book)\n";
+	my $diff = $ab ? "$full (in address book):\n" : "$full (not in address book):\n";
 
 	if(my $old = $self->original) {
 		$ab = $old->addressbook
