@@ -1,4 +1,4 @@
-# $Id: Domain.pm 41252 2014-03-31 14:24:11Z wsl $
+# $Id: Domain.pm 41867 2014-07-03 15:23:19Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/Database/Domain.pm $
 
 use utf8;
@@ -12,7 +12,6 @@ use Clarity -self;
 field db;
 
 field id;
-field name => sub { shift->names->[0] };
 field names;
 
 sub same {
@@ -20,6 +19,23 @@ sub same {
 	return scalar grep { lc($_) eq $name } @{$self->names};
 }
 
+sub name {
+	return $self->names->[0];
+}
+
+sub full {
+	return $self->names->[0];
+}
+
+sub toString {
+	my $names = $self->names;
+	if(@$names > 1) {
+		return $names->[0].' ('.join(', ', @$names[1..$#$names]).')';
+	} else {
+		return $names->[0];
+	}
+}
+
 sub TO_JSON {
-    return $self->names;
+	return $self->names;
 }
