@@ -1,4 +1,4 @@
-# $Id: Request.pm 42214 2014-09-11 11:10:43Z wsl $
+# $Id: Request.pm 46806 2017-07-26 15:48:10Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/WS/Alias/Post/Request.pm $
 
 use utf8;
@@ -78,15 +78,15 @@ field new_alias => sub {
 			my $new = $alias->toString;
 			if(my $original = $alias->original) {
 				my $address = $original->full;
-				my $old = $alias->original->toString;
+				my $old = $original->toString;
 				my $text = "$what $who updated alias:\n\told: $old\n\tnew: $new\n";
 				warn $text;
-				$self->mailtje("[kiki] $who updated $address", $text);
+				$self->mailtje("[kiki] $who updated $address", $alias->diff);
 			} else {
 				my $address = $alias->full;
 				my $text = "$what $who created alias:\n\tnew: $new\n";
 				warn $text;
-				$self->mailtje("[kiki] $who created $address", $text);
+				$self->mailtje("[kiki] $who created $address", $alias->diff);
 			}
 
 			$alias->store;
